// $Id: FileInfo.cpp,v 1.17 2014/04/29 17:08:08 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "FileInfo.h"
#include "Debug.h"
#include "TimeStamp.h"
#include "XmlDef.h"


//________________________________________________________________
FileInfo::FileInfo( const QDomElement& element ):
    BaseFileInfo( element ),
    Counter( "FileInfo" ),
    status_( Success | Overwrite )
{

    Debug::Throw( "FileInfo::FileInfo (dom).\n" );

    // parse attributes
    QDomNamedNodeMap attributes( element.attributes() );
    for( int i=0; i<attributes.count(); i++ )
    {

        QDomAttr attribute( attributes.item( i ).toAttr() );
        if( attribute.isNull() ) continue;
        else if( attribute.name() == Xml::Status ) setStatus( StatusFlags( attribute.value().toInt() ) );

    }

}

//________________________________________________________________
QDomElement FileInfo::domElement( QDomDocument& document ) const
{

    Debug::Throw( "FileInfo::DomElement.\n" );
    QDomElement out( BaseFileInfo::domElement( document ) );
    out.setAttribute( Xml::Status, QString::number( status() ) );
    return out;

}

//________________________________________________________________
File FileInfo::path( void ) const
{

    if( isLocal() ) return file().path();
    else {

        const int position( file().endsWith( '/' ) ?
            file().left( file().size()-1).lastIndexOf( '/' ):
            file().lastIndexOf( '/' ) );
        return position >= 0 ? file().left( position+1 ) : "/";
    }

}
