#ifndef FtpCommandModel_h
#define FtpCommandModel_h

// $Id: FtpCommandModel.h,v 1.22 2014/09/12 08:43:12 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"
#include "ListModel.h"
#include "FtpCommand.h"

#include <QHash>

//! Job model. Stores job information for display in lists
class FtpCommandModel : public ListModel<FtpCommand>, public Counter
{

    //! Qt meta object declaration
    Q_OBJECT

    public:

    //! constructor
    FtpCommandModel( QObject* = 0 );

    //! destructor
    virtual ~FtpCommandModel()
    {}

    //! column type enumeration
    enum ColumnType
    {
        Name,
        Filename,
        nColumns
    };

    //!@name methods reimplemented from base class
    //@{

    //! data
    virtual QVariant data( const QModelIndex&, int ) const;

    //! header data
    virtual QVariant headerData( int, Qt::Orientation, int = Qt::DisplayRole ) const;

    //! number of columns for a given index
    virtual int columnCount( const QModelIndex& = QModelIndex() ) const
    { return nColumns; }

    //@}

    public Q_SLOTS:

    //! add command
    virtual void add( const FtpCommand& command )
    { ListModel<FtpCommand>::add( command ); }

    //! add commands
    virtual void add( const FtpCommand::List& commands )
    { ListModel<FtpCommand>::add( commands ); }

    //! remove
    virtual void remove( const FtpCommand& command )
    { ListModel<FtpCommand>::remove( command ); }

    protected:

    //! sort
    virtual void _sort( int, Qt::SortOrder = Qt::AscendingOrder )
    {}

    private Q_SLOTS:

    //! update configuration
    void _updateConfiguration( void );

    private:

    //! install pixmaps
    void _installIcons( void ) const;

    //! list column names
    static const QString columnTitles_[nColumns];

    //! icon cache
    using IconCache = QHash<FtpCommand::Type, QIcon>;

    //! type icon cache for local modifications
    static IconCache& _icons();

};

#endif
